def Manfred():
    import PLManfred.skript as s
    s.setup()
